@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is a kernel build script for Fedora 10's 2.6.27 kernel.
+# This is a kernel build script for Fedora 8's 2.6.26 kernel.
 #
 
 die () {
@@ -10,23 +10,23 @@ die () {
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-2.6.27.12-170.2.5.fc10.src.rpm ]
+if [ ! -r kernel-2.6.26.8-57.fc8.src.rpm ]
 then
-    wget http://ftp.riken.jp/Linux/fedora/development/source/SRPMS/kernel-2.6.27.12-170.2.5.fc10.src.rpm || die "Can't download source package."
+    wget http://ftp.riken.jp/Linux/fedora/updates/8/SRPMS.newkey/kernel-2.6.26.8-57.fc8.src.rpm || die "Can't download source package."
 fi
-rpm -ivh kernel-2.6.27.12-170.2.5.fc10.src.rpm || die "Can't install source package."
+rpm -ivh kernel-2.6.26.8-57.fc8.src.rpm || die "Can't install source package."
 
-cd /root/rpmbuild/SOURCES/ || die "Can't chdir to /root/rpmbuild/SOURCES/ ."
-if [ ! -r ccs-patch-1.6.6-20090202.tar.gz ]
+cd /usr/src/redhat/SOURCES/ || die "Can't chdir to /usr/src/redhat/SOURCES/ ."
+if [ ! -r ccs-patch-1.6.6-20090314.tar.gz ]
 then
-    wget http://osdn.dl.sourceforge.jp/tomoyo/30297/ccs-patch-1.6.6-20090202.tar.gz || die "Can't download patch."
+    wget http://osdn.dl.sourceforge.jp/tomoyo/30297/ccs-patch-1.6.6-20090314.tar.gz || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
-cp -p /root/rpmbuild/SPECS/kernel.spec . || die "Can't copy spec file."
+cp -p /usr/src/redhat/SPECS/kernel.spec . || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
---- kernel.spec	2009-01-21 15:16:42.000000000 +0900
-+++ kernel.spec	2009-01-27 16:48:33.000000000 +0900
+--- kernel.spec	2008-12-19 08:34:39.000000000 +0900
++++ kernel.spec	2009-01-27 17:09:58.000000000 +0900
 @@ -12,7 +12,7 @@
  # that the kernel isn't the stock distribution kernel, for example,
  # by setting the define to ".local" or ".bz123456"
@@ -36,7 +36,7 @@ patch << "EOF" || die "Can't patch spec file."
  
  # fedora_build defines which build revision of this kernel version we're
  # building. Rather than incrementing forever, as with the prior versioning
-@@ -384,6 +384,11 @@
+@@ -389,6 +389,11 @@
  # to versions below the minimum
  #
  
@@ -48,16 +48,7 @@ patch << "EOF" || die "Can't patch spec file."
  #
  # First the general kernel 2.6 required versions as per
  # Documentation/Changes
-@@ -422,7 +427,7 @@
- # Packages that need to be installed before the kernel is, because the %post
- # scripts use them.
- #
--%define kernel_prereq  fileutils, module-init-tools, initscripts >= 8.11.1-1, mkinitrd >= 6.0.61-1, kernel-firmware >= %{rpmversion}-%{pkg_release}
-+%define kernel_prereq  fileutils, module-init-tools, initscripts >= 8.11.1-1, mkinitrd >= 6.0.61-1
- 
- #
- # This macro does requires, provides, conflicts, obsoletes for a kernel package.
-@@ -450,7 +455,7 @@
+@@ -442,7 +447,7 @@
  AutoProv: yes\
  %{nil}
  
@@ -66,8 +57,8 @@ patch << "EOF" || die "Can't patch spec file."
  Group: System Environment/Kernel
  License: GPLv2
  URL: http://www.kernel.org/
-@@ -841,7 +846,7 @@
- Provides: kernel-devel-uname-r = %{KVERREL}%{?1:.%{1}}\
+@@ -788,7 +793,7 @@
+ Provides: kernel-devel = %{rpmversion}-%{release}%{?1}\
  AutoReqProv: no\
  Requires(pre): /usr/bin/find\
 -%description -n kernel%{?variant}%{?1:-%{1}}-devel\
@@ -75,18 +66,18 @@ patch << "EOF" || die "Can't patch spec file."
  This package provides kernel headers and makefiles sufficient to build modules\
  against the %{?2:%{2} }kernel package.\
  %{nil}
-@@ -1343,6 +1348,10 @@
+@@ -1293,6 +1298,10 @@
  
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.6.6-20090202.tar.gz
-+patch -sp1 < patches/ccs-patch-2.6.27-fedora-10.diff
++tar -zxf %_sourcedir/ccs-patch-1.6.6-20090314.tar.gz
++patch -sp1 < patches/ccs-patch-2.6.26-fedora-8.diff
 +
  %endif
  
  # Any further pre-build tree manipulations happen here.
-@@ -1369,6 +1378,9 @@
+@@ -1318,6 +1327,9 @@
  for i in *.config
  do
    mv $i .config
