@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is a kernel build script for openSUSE 11.1's 2.6.27 kernel.
+# This is a kernel build script for openSUSE 10.2's 2.6.18 kernel.
 #
 
 die () {
@@ -13,9 +13,9 @@ cd /usr/lib/rpm/ || die "Can't chdir to /usr/lib/rpm/ ."
 if ! grep -q ccs-kernel find-supplements.ksyms
 then
 	patch << "EOF" || die "Can't patch find-supplements.ksyms ."
---- find-supplements.ksyms	2008-05-22 10:02:00.000000000 +0900
-+++ find-supplements.ksyms	2008-06-11 11:04:06.000000000 +0900
-@@ -7,6 +7,7 @@
+--- find-supplements.ksyms	2008-04-16 14:18:13.000000000 +0900
++++ find-supplements.ksyms	2008-04-16 14:19:06.000000000 +0900
+@@ -6,6 +6,7 @@
  case "$1" in
  kernel-module-*)    ;; # Fedora kernel module package names start with
  		       # kernel-module.
@@ -60,53 +60,52 @@ fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-source-2.6.27.7-9.1.src.rpm ]
+if [ ! -r kernel-source-2.6.18.8-0.13.src.rpm ]
 then
-    wget http://download.opensuse.org/source/distribution/11.1/repo/oss/suse/src/kernel-source-2.6.27.7-9.1.src.rpm || die "Can't download source package."
+    wget http://ftp.riken.jp/Linux/suse/suse/update/10.2/rpm/src/kernel-source-2.6.18.8-0.13.src.rpm || die "Can't download source package."
 fi
-rpm -ivh kernel-source-2.6.27.7-9.1.src.rpm || die "Can't install source package."
+rpm -ivh kernel-source-2.6.18.8-0.13.src.rpm || die "Can't install source package."
 
 cd /usr/src/packages/SOURCES/ || die "Can't chdir to /usr/src/packages/SOURCES/ ."
-if [ ! -r ccs-patch-1.6.6-20090202.tar.gz ]
+if [ ! -r ccs-patch-1.6.6-20090314.tar.gz ]
 then
-    wget http://osdn.dl.sourceforge.jp/tomoyo/30297/ccs-patch-1.6.6-20090202.tar.gz || die "Can't download patch."
+    wget http://osdn.dl.sourceforge.jp/tomoyo/30297/ccs-patch-1.6.6-20090314.tar.gz || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 cp -p /usr/src/packages/SOURCES/kernel-default.spec . || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
---- kernel-default.spec	2008-12-05 10:41:43.000000000 +0900
-+++ kernel-default.spec	2008-12-19 09:30:25.000000000 +0900
-@@ -57,13 +57,13 @@
- %if %build_vanilla || %build_kdump || %CONFIG_MODULES != "y"
- %define split_packages 0
- %else
--%define split_packages 1
-+%define split_packages 0
- %endif
+--- kernel-default.spec	2008-10-17 00:22:46.000000000 +0900
++++ kernel-default.spec	2008-10-18 14:36:07.000000000 +0900
+@@ -30,13 +30,13 @@
+ %define build_um  %([ default != um ] ; echo $?)
+ %define build_vanilla  %([ default != vanilla ] ; echo $?)
  
 -Name:           kernel-default
 +Name:           ccs-kernel-default
- Summary:        The Standard Kernel
- Version:        2.6.27.7
--Release:        9
-+Release:        9_tomoyo_1.6.6
- License:        GPL v2 only
+ %ifarch ia64
+ # arch/ia64/scripts/unwcheck.py
+ BuildRequires:  python
+ %endif
+ Version:        2.6.18.8
+-Release: 0.13
++Release: 0.13_tomoyo_1.6.6
+ Summary:        The Standard Kernel for both Uniprocessor and Multiprocessor Systems
+ License:        GPL v2 or later
  Group:          System/Kernel
- Url:            http://www.kernel.org/
-@@ -308,6 +308,10 @@
+@@ -242,6 +242,10 @@
  %build
  source .rpm-defs
- cd linux-2.6.27
+ cd linux-2.6.18
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.6.6-20090202.tar.gz
-+patch -sp1 < patches/ccs-patch-2.6.27-suse-11.1.diff
++tar -zxf %_sourcedir/ccs-patch-1.6.6-20090314.tar.gz
++patch -sp1 < patches/ccs-patch-2.6.18-suse-10.2.diff
 +cat config.ccs >> .config
  cp .config .config.orig
  %if %{tolerate_unknown_new_config_options}
  MAKE_ARGS="$MAKE_ARGS -k"
 EOF
-sed -e 's:^Provides:#Provides:' -e 's:^Obsoletes:#Obsoletes:' -e 's:-n kernel:-n ccs-kernel:' kernel-default.spec > ccs-kernel.spec || die "Can't edit spec file."
+sed -e 's:^Provides:#Provides:' -e 's:^Obsoletes:#Obsoletes:' kernel-default.spec > ccs-kernel.spec || die "Can't edit spec file."
 echo ""
 echo ""
 echo ""
